@@ -221,7 +221,7 @@ class WebServer(objects.Thread):
 			return r3sponse.error(f"The {self.id} is already running.")
 	def stop(self):
 		if not self.running: 
-			return r3sponse.error(f"The {self.id} is not running.")
+			return r3sponse.error(f"{self.__traceback__(function='stop')}: The {self.id} is not running.")
 		processes = processes(includes=f"--syst3m-webserver-tag {self.tag}")
 		if not processes.success: return response
 		if len(processes.processes) <= 1:
@@ -240,7 +240,11 @@ class WebServer(objects.Thread):
 			try: success = bool(response["success"])
 			except: success = True
 			if not success: return response
-		return r3sponse.success(f"Successfully started thread [{thread}].")
+		try:
+			id = thread.id
+		except:
+			id = str(thread)
+		return r3sponse.success(f"Successfully started [{id}].")
 	def get_thread(self, group="daemos", id=None):
 		response = self.get(group=group, id=id)
 		if not response.success: 
