@@ -17,6 +17,7 @@ vars = r3sponse.ResponseObject({
 	"homes": gfp.base(path=os.environ.get('HOME')),
 	"home": gfp.clean(os.environ.get('HOME')+"/"),
 	"python3":"python3",
+	"executable":sys.executable,
 })
 if vars.os in ["darwin"]:  
 	vars.os = "macos"
@@ -30,6 +31,7 @@ options = r3sponse.ResponseObject({
 	"cli": env.get_boolean("CLI", default=False),
 	"json": cl1.arguments_present(["-j", "--json"]),
 	"log_level": int(cl1.get_argument("--log-level", required=False, default=env.get_integer("LOG_LEVEL", default=0))),
+	"forced": cl1.arguments_present(["--forced", "-f"], default=env.get("FORCED", default=False, format=bool)),
 })
 
 # get operating system.
@@ -60,7 +62,7 @@ def alias(
 		if l_alias != None: alias = l_alias
 		#file = f"""package={executable}/\nargs=""\nfor var in "$@" ; do\n   	if [ "$args" == "" ] ; then\n   		args=$var\n   	else\n   		args=$args" "$var\n   	fi\ndone\npython3 $package $args\n"""
 		sudo = Boolean("--sudo" in sys.argv).string(true="sudo ",false="")
-		file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nif os.path.exists("/usr/bin/python3"): os.system("/usr/bin/python3 "+package+" "+s)\nelse:  os.system("python3 "+package+" "+s)"""
+		file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nif os.path.exists("/usr/bin/python3"): os.system("/usr/bin/python3 "+package+" "+s)\nelse:  os.system("python3 "+package+" "+s)\n#os.system("python3 "+package+" "+s)"""
 		os.system(f"{sudo}touch {path}")
 		os.system(f"{sudo}chmod +x {path}")
 		os.system(f"{sudo}chown {vars.user}:{vars.group} {path}")
@@ -182,4 +184,32 @@ def processes(
 		"processes":processes,
 	})
 
+# install requirements.
+def install_requirements(
+	# the requirements (#1).
+	#	str instance: path to file.
+	#	list instance: pip requirements in list
+	requirements,
+	# the silent option.
+	silent=False,
+	# the log level.
+	log_level=options.log_level,
+):
+	options = ""
+	if isinstance(requirements, (str, String)):
+		
+		msg = f"Installing pip requirements [{requirements}]."
+		if not os.path.exists(requirements):
+			raise ValueError(f"Requirements file [{requirements}] does not exist.")
+		if not os.path.isdir(requirements):
+			options += "-r "
+	elif isinstance(requirements, (list, Array)):
+		msg = f"Installing {len(requirements)} pip requirement(s)."
+		requirements = Array(requirements).string(joiner=" ")
+	_python_ = "python3"
+	if vars.os in ["macos"]:
+		_python_ = "/usr/bin/python3"
+	if log_level >= 0: print(msg)
+	os.system(f"{_python_} -m pip install {options}{requirements} {Boolean(silent).string(true='2> /dev/null', false='')}")
+
 #
\ No newline at end of file
