@@ -48,9 +48,9 @@ class RestAPI(objects.Object):
 		if response_object.status_code != 200:
 			return r3sponse.error(f"Invalid request ({url}) [{response_object.status_code}]: {response_object.text}")
 		if json:
-			try: response = r3sponse.ResponseObject(json=output)
+			try: response = r3sponse.ResponseObject(json=response_object.json())
 			except Exception as e: 
-				return r3sponse.error(f"Unable to serialize output: {response_object}.")
+				return r3sponse.error(f"Unable to serialize output: {response_object}, error: {e}.")
 			return response
 		return response_object
 
